#
# spec file for package build
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needsrootforbuild
# needsbinariesforbuild


%if 0%{?suse_version}
%define __pkg_name build
%else
%define __pkg_name obs-build
%endif

Name:           %{__pkg_name}
Summary:        A Script to Build SUSE Linux RPMs
License:        GPL-2.0-only OR GPL-3.0-only
Group:          Development/Tools/Building
Version:        20250304
Release:        1.1
Source:         obs-build-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
#!BuildIgnore:  build-mkbaselibs build-mkbaselibs-sle
# Keep the following dependencies in sync with obs-worker package
Requires:       bash
Requires:       binutils
Requires:       findutils
Requires:       perl
Requires:       tar
# needed for fuser
Requires:       psmisc
# just to verify existence of packages
BuildRequires:  bash
BuildRequires:  binutils
BuildRequires:  perl
BuildRequires:  psmisc
BuildRequires:  tar
# For testcases
BuildRequires:  perl(Date::Parse)
BuildRequires:  perl(Test::Harness)
BuildRequires:  perl(Test::More)
%if 0%{?fedora}
Requires:       perl-TimeDate
Requires:       perl(LWP::Protocol::https)
Requires:       perl(XML::Parser)
BuildRequires:  perl-TimeDate
%endif
Conflicts:      bsdtar < 2.5.5
%if 0%{?suse_version}
Conflicts:      qemu < 2.5.0
%endif
BuildRequires:  perl(Date::Parse)
BuildRequires:  perl(Test::Harness)
BuildRequires:  perl(Test::More)
%if 0%{?suse_version} >= 1200
BuildRequires:  perl(YAML::LibYAML)
%endif
%if 0%{?suse_version} > 1000 || 0%{?centos_version} >= 800 || 0%{?rhel_version} >= 800 || 0%{?fedora_version} >= 21
# None of them are actually required for core features.
# Perl helper scripts use them.
Recommends:     perl(Archive::Tar)
Recommends:     /sbin/mkfs.ext4
Recommends:     /usr/bin/qemu-kvm
Recommends:     bsdtar
Recommends:     hostname
Recommends:     qemu-linux-user
Recommends:     xfsprogs
Recommends:     zstd
Recommends:     perl(Config::IniFiles)
Recommends:     perl(Date::Language)
Recommends:     perl(Date::Parse)
Recommends:     perl(LWP::UserAgent)
Recommends:     perl(Pod::Usage)
Recommends:     perl(Time::Zone)
Recommends:     perl(URI)
Recommends:     perl(XML::Parser)
Recommends:     perl(YAML::LibYAML)
# for vc:
Recommends:     /usr/bin/dnsdomainname
Recommends:     /usr/bin/rpmdev-packager
%endif

%if 0%{?suse_version} > 1120 || ! 0%{?suse_version}
Requires:       %{__pkg_name}-mkbaselibs
%endif

%if 0%{?suse_version} > 1120 || 0%{?mdkversion}
Recommends:     %{__pkg_name}-mkdrpms
%endif

# With fedora 33 the POSIX module was split out of the perl
# package
BuildRequires:  perl(POSIX)
Requires:       perl(POSIX)

%description
This package provides a script for building RPMs for SUSE Linux in a
chroot environment.


%if 0%{?suse_version} > 1120 || ! 0%{?suse_version}

%package mkbaselibs
Summary:        Tools to generate base lib packages
# NOTE: this package must not have dependencies which may break boot strapping (eg. perl modules)
Group:          Development/Tools/Building

%description mkbaselibs
This package contains the parts which may be installed in the inner build system
for generating base lib packages.

%package mkdrpms
Summary:        Tools to generate delta rpms
Group:          Development/Tools/Building
Requires:       deltarpm
# XXX: we wanted to avoid that but mkdrpms needs Build::Rpm::rpmq
Requires:       %{__pkg_name}

%description mkdrpms
This package contains the parts which may be installed in the inner build system
for generating delta rpm packages.

%endif

%define initvm_arch %{_host_cpu}
%if "%{_host_cpu}" == "i686"
%define initvm_arch i586
%endif

%package initvm-%{initvm_arch}
Summary:        Virtualization initializer for emulated cross architecture builds
Group:          Development/Tools/Building
Requires:       %{__pkg_name}
BuildRequires:  gcc
BuildRequires:  glibc-devel
Provides:       %{__pkg_name}-initvm
Obsoletes:      %{__pkg_name}-initvm
%if 0%{?suse_version} > 1200
BuildRequires:  glibc-devel-static
%endif

%description initvm-%{initvm_arch}
This package provides a script for building RPMs for SUSE Linux in a
chroot or a secure virtualized

%prep
%setup -q -n obs-build-%version

%build
%if 0%{?suse_version}
# initvm
make CFLAGS="$RPM_BUILD_FLAGS" initvm-all
%endif

%install
# initvm
%if 0%{?suse_version}
make DESTDIR=%{buildroot} initvm-install
strip %{buildroot}/usr/lib/build/initvm.*
export NO_BRP_STRIP_DEBUG="true"
%endif

# main
make DESTDIR=%{buildroot} install

# tweak default config on suse
%if 0%{?suse_version}
cd %{buildroot}/usr/lib/build/configs/
SUSE_V=%{?suse_version}
SLE_V=%{?sle_version}
%if 0%{?sle_version} && 0%{?is_opensuse} && %suse_version == 1315
# this is SUSE Leap 42.X
ln -s sl42.${SLE_V:3:1}.conf default.conf
%endif
%if 0%{?sle_version} && 0%{?is_opensuse} && %suse_version > 1315
# this is SUSE Leap 15 and higher
ln -s sl${SLE_V:0:2}.${SLE_V:3:1}.conf default.conf
%endif
%if !0%{?sle_version} && ( 0%{?suse_version} <= 1310 || 0%{?suse_version} == 1320 || 0%{?suse_version} == 1330 )
# this is old openSUSE releases and Factory
ln -s sl${SUSE_V:0:2}.${SUSE_V:2:1}.conf default.conf
%endif
%if !0%{?sle_version} && ( 0%{?suse_version} == 1699 )
ln -s tumbleweed.conf default.conf
%endif
%if 0%{?sle_version} && !0%{?is_opensuse}
# this is SUSE SLE 12 and higher
ln -s sle${SLE_V:0:2}.${SLE_V:3:1}.conf default.conf
%endif
%if 0%{?sles_version} == 1110
# this is SUSE SLE 11
ln -s sles11sp2.conf default.conf
%endif
%if 0%{?suse_version} == 1600
# this is SUSE ALP
ln -s alp.conf default.conf
%endif
# make sure that we have a config
test -e default.conf || exit 1
%endif

# tweak baselibs config on suse
%if 0%{?suse_version}
cd %{buildroot}/usr/lib/build
%if %suse_version == 1500
# SLE 15 / Leap 15
ln -sf baselibs_configs/baselibs_global-sle15.conf baselibs_global.conf
%endif
%if %suse_version == 1315
# SLE 12 / Leap 42
ln -sf baselibs_configs/baselibs_global-sle12.conf baselibs_global.conf
%endif
%if %suse_version <= 1110
# SLE 11
ln -sf baselibs_configs/baselibs_global-sle11.conf baselibs_global.conf
%endif
test -e baselibs_global.conf || exit 1
%endif

%check
for i in build build-* ; do bash -n $i || exit 1 ; done

# run perl module unit tests
LANG=C make test || exit 1

if [ `whoami` != "root" ]; then
  echo "WARNING: Not building as root, build test did not run!"
  exit 0
fi
if [ ! -f "%{buildroot}/usr/lib/build/configs/default.conf" ]; then
  echo "WARNING: No default config, build test did not run!"
  exit 0
fi
# get back the default.conf link
cp -av %{buildroot}/usr/lib/build/configs/default.conf configs/
# do not get confused when building this already with build:
export BUILD_IGNORE_2ND_STAGE=1
# use our own build code
export BUILD_DIR=$PWD

# simple chroot build test
cd test
# target is autodetected
%if 0%{?sles_version}
echo "SLES config differs currently on purpose between OBS and build script."
echo "Skipping test case"
exit 0
%endif
%if 0%{?qemu_user_space_build}
echo "test suite is not prepared to run using qemu linux user"
echo "Skipping test case"
exit 0
%endif
# we need to patch the not packaged configs, due to the buildignore
sed -i 's,build-mkbaselibs,,' ../configs/*.conf
if [ ! -e /.build.packages/rpmlint-Factory.rpm ]; then
  sed -i 's,rpmlint-Factory,,' ../configs/*.conf
fi
if [ ! -e /.build.packages/rpmlint-strict.rpm ]; then
  sed -i 's,rpmlint-strict,,' ../configs/*.conf
fi
if [ ! -e /.build.packages/rpmlint-mini.rpm ]; then
  sed -i 's,rpmlint-mini,,' ../configs/*.conf
fi
./testbuild.sh /.build.binaries/

%files
%defattr(-,root,root)
%doc README.md docs
/usr/bin/build
/usr/bin/pbuild
/usr/bin/buildvc
/usr/bin/unrpm
/usr/lib/build
%config(noreplace) /usr/lib/build/emulator/emulator.sh
%{_mandir}/man1/build.1*
%{_mandir}/man1/unrpm.1*
%{_mandir}/man1/buildvc.1*
%{_mandir}/man1/pbuild.1*
%if 0%{?suse_version}
%exclude /usr/lib/build/initvm.*
%endif

%if 0%{?suse_version} > 1120 || ! 0%{?suse_version}
%exclude /usr/lib/build/mkbaselibs
%exclude /usr/lib/build/baselibs*
%exclude /usr/lib/build/mkdrpms

%files mkbaselibs
%defattr(-,root,root)
%dir /usr/lib/build
/usr/lib/build/mkbaselibs
/usr/lib/build/baselibs*

%files mkdrpms
%defattr(-,root,root)
%dir /usr/lib/build
/usr/lib/build/mkdrpms
%endif

%if 0%{?suse_version}
%files initvm-%{initvm_arch}
%defattr(-,root,root)
/usr/lib/build/initvm.*
%endif

%changelog
* Tue Mar  4 2025 Adrian Schröter <adrian@suse.de>
- fixes for POSIX compatibility for obs-docker-support adn
  mkbaselibs
- Add support for apk in docker/podman builds
- Add support for 'wget' in Docker images
- Fix debian support for Dockerfile builds
- Fix preinstallimages in containers
- mkosi: add back system-packages used by build-recipe directly
- pbuild: parse the Release files for debian repos
* Thu Feb  6 2025 Adrian Schröter <adrian@suse.de>
- mkosi: drop most systemd/build-packages deps and use obs_scm
    directory as source if present
- improve source copy handling
- Introduce --repos-directory and --containers-directory options
* Thu Jan 30 2025 Adrian Schröter <adrian@suse.de>
- productcompose: support of building against a baseiso
- preinstallimage: avoid inclusion of build script generated files
- preserve timestamps on sources copy-in for kiwi and productcompose
- alpine package support updates
- tumbleweed config update
* Mon Jan 13 2025 Adrian Schröter <adrian@suse.de>
- debian: Support installation of foreign architecture packages
    (required for armv7l setups)
- Parse unknown timezones as UTC
- Apk (Alpine Linux) format support added
- Implement default value in parameter expansion
- Also support supplements that use & as "and"
- Add workaround for skopeo's argument parser
- add cap-htm=off on power9
- Fixed usage of chown calls
- Remove leading `go` from `purl` locators
* Thu Nov 14 2024 Adrian Schröter <adrian@suse.de>
- container related:
  * Implement support for the new <containers> element in kiwi recipes
  * Fixes for SBOM and dependencies of multi stage container builds
  * obs-docker-support: enable dnf and yum substitutions
- Arch Linux:
  * fix file path for Arch repo
  * exclude unsupported arch
  * Use root as download user
- build-vm-qemu: force sv48 satp mode on riscv64
- mkosi:
  * Create .sha256 files after mkosi builds
  * Always pass --image-version to mkosi
- General improvements and bugfixes (mkosi, pbuild, appimage/livebuild,
    obs work detection, documention, SBOM)
- Support slsa v1 in unpack_slsa_provenance
- generate_sbom: do not clobber spdx supplier
- Harden export_debian_orig_from_git (boo#1230469)
* Fri Sep 13 2024 Adrian Schröter <adrian@suse.de>
- SBOM generation:
  - Adding golang introspection support
  - Adding rust binary introspection support
  - Keep track of unknwon licenses and add a "hasExtractedLicensingInfos"
    section
  - Also normalize licenses for cyclonedx
  - Make generate_sbom errors fatal
  - general improvements
- Fix noprep building not working because the buildir is removed
- kiwi image: also detect a debian build if /var/lib/dpkg/status is present
- Do not use the Encode module to convert a code point to utf8
- Fix personality syscall number for riscv
- add more required recommendations for KVM builds
- set PACKAGER field in build-recipe-arch
- fix writing _modulemd.yaml
- pbuild: support --release and --baselibs option
- container:
  - copy base container information from the annotation into the
    containerinfo
  - track base containers over multiple stages
  - always put the base container last in the dependencies
* Tue Jul 23 2024 Adrian Schröter <adrian@suse.de>
- providing fileprovides in createdirdeps tool
- Introduce buildflag nochecks
* Thu Jul 11 2024 Adrian Schröter <adrian@suse.de>
- productcompose: support __all__ option
- config update: tumbleweed using preinstallexpand
- minor improvements
* Wed Jun 12 2024 mls@suse.de
- tumbleweed build config update
- support the %%load macro
- improve container filename generation (docker)
- fix hanging curl calls during build (docker)
- productcompose: fix milestone query
* Thu May 16 2024 Adrian Schröter <adrian@suse.de>
- tumbleweed build config update
- 15.6 build config fixes
- sourcerpm & sourcedep handling fixes
- productcompose:
  - Fix milestone handling
  - Support bcntsynctag
- Adding debian support to generate_sbom
- Add syscall for personality switch on loongarch64 kernel
- vm-build: ext3 & ext4: fix disk space allocation
- mkosi format updates, not fully working yet
- pbuild exception fixes
- Fixes for current fedora and centos distros
- Don't copy original dsc sources if OBS-DCH-RELEASE set
- Unbreak parsing of sources/patches
- Support ForceMultiVersion in the dockerfile parser
- Support %%bcond of rpm 4.17.1
* Wed Mar 13 2024 Adrian Schröter <adrian@suse.de>
- Add a hack for systemd 255.3, creating an empty /etc/os-release
  if missing after preinstall.
- docker: Fix HEAD request in dummyhttpserver
- pbuild: Make docker-nobasepackages expand flag the default
- rpm: Support a couple of builtin rpm macros
- rpm: Implement argument expansion for define/with/bcond...
- Fix multiline macro handling
- Accept -N parameter of %%autosetup
- documentation updates
- various code cleanup and speedup work.
* Wed Feb 21 2024 Adrian Schröter <adrian@suse.de>
- ProductCompose: multiple improvements
- Add buildflags:define_specfile support
- Fix copy-in of git subdirectory sources
- pbuild: Speed up XML parsing
- pubild: product compose support
- generate_sbom: add help option
- podman: enforce runtime=runc
- Implement direct conflicts from the distro config
- changelog2spec: fix time zone handling
- Do not unmount /proc/sys/fs/binfmt_misc before runnint the check scripts
- spec file cleanup
- documentation updates
* Thu Jan 11 2024 Adrian Schröter <adrian@suse.de>
- productcompose:
  - support schema 0.1
  - support milestones
- Leap 15.6 config
- SLE 15 SP6 config
* Fri Dec  1 2023 Adrian Schröter <adrian@suse.de>
- productcompose: follow incompatible flavor syntax change
- pbuild: support for zstd
* Fri Dec  1 2023 Adrian Schröter <adrian@suse.de>
- fixed handling for cmdline parameters via kernel packages
* Thu Nov 30 2023 Adrian Schröter <adrian@suse.de>
- productcompose:
  * BREAKING: support new schema
  * adapt flavor architecture parsing
* Tue Nov 28 2023 Adrian Schröter <adrian@suse.de>
- productcompose:
  * support filtered package lists
  * support default architecture listing
  * fix copy in binaries in VM builds^
* Mon Nov 20 2023 Adrian Schröter <adrian@suse.de>
- obsproduct build type got renamed to productcompose
* Mon Nov 20 2023 Adrian Schröter <adrian@suse.de>
- Support zstd compressed rpm-md meta data (bsc#1217269)
- Added Debian 12 configuration
- First ObsProduct build format support
* Fri Nov  3 2023 Adrian Schröter <adrian@suse.de>
- fix SLE 15 SP5 build configuration
- Improve user agent handling for obs repositories
* Fri Oct 27 2023 Adrian Schröter <adrian@suse.de>
- Docker:
  - Support flavor specific build descriptions via Dockerfile.$flavor
  - support "PlusRecommended" hint to also provide recommended packages
  - use the name/version as filename if both are known
  - Produce docker format containers by default
- pbuild: Support for signature authentification of OBS resources
- Fix wiping build root for --vm-type podman
- Put BUILD_RELEASE and BUILD_CHANGELOG_TIMESTAMP in the /.buildenv
- build-vm-kvm: use -cpu host on riscv64
- small fixes and cleanups
* Fri Aug 11 2023 Adrian Schröter <adrian@suse.de>
- Added parser for BcntSyncTag in sources
* Tue Aug  8 2023 Adrian Schröter <adrian@suse.de>
- pbuild:
  * fix dependency expansion for build types other than spec
  * Reworked cycle handling code
  * add --extra-packs option
  * add debugflags option
- Pass-through --buildtool-opt
- Parse Patch and Source lines more accurately
- fix tunefs functionality
- minor bugfixes
* Wed Jun 28 2023 Adrian Schröter <adrian@suse.de>
- --vm-type=podman added (supports also root-less builds)
- Also support build constraints in the Dockerfile
- minor fixes
* Tue May  2 2023 Adrian Schröter <adrian@suse.de>
- Add SUSE ALP build config
* Tue Apr 25 2023 Adrian Schröter <adrian@suse.de>
- BREAKING: Record errors when parsing the project config
    former behaviour was undefined
- container: Support compression format configuration option
- Don't setup ccache with --no-init
- improved loongarch64 support
- sbom: SPDX supplier tag added
- kiwi: support different versions per profile
- preinstallimage: fail when recompression fails
- Add support for recommends and supplements dependencies
- Support the "keepfilerequires" expand flag
- add '--buildtool-opt=OPTIONS' to pass options to the used build tool
- distro config updates
  * ArchLinux
  * Tumbleweed
- documentation updates
* Mon Apr 24 2023 Dominique Leuenberger <dimstar@opensuse.org>
- openSUSE Tumbleweed: sync config and move to suse_version 1699.
* Tue Mar 14 2023 Adrian Schröter <adrian@suse.de>
- universal post-build hook, just place a file in /usr/lib/build/post_build.d/
- mkbaselibs/hwcaps, fix pattern name once again (x86_64_v3)
- KiwiProduct: add --use-newest-package hint if the option is set
* Tue Feb 28 2023 Adrian Schröter <adrian@suse.de>
- Dockerfile support:
  * export multibuild flavor as argument
  * allow parameters in FROM .. scratch lines
  * include OS name in build result if != linux
- Workaround directory->symlink usrmerge problems for cross arch sysroot
- multiple fixes for SBOM support
* Wed Feb 15 2023 Adrian Schröter <adrian@suse.de>
- KIWI VM image SBOM support added
* Wed Feb 15 2023 Adrian Schröter <adrian@suse.de>
- CycloneDX SBOM support added
* Fri Feb 10 2023 Adrian Schröter <adrian@suse.de>
- added support for generating VCS url information into rpms
* Wed Feb  8 2023 Adrian Schröter <adrian@suse.de>
- SPDX SBOM generation for container and product builds
- Revert & Redo "Better filetype detection for temp changes files"
- Fix typo in glibc hwcaps supplements
- Implement lua string macros
* Mon Jan  2 2023 Adrian Schröter <adrian@suse.de>
- configure mkbaselibs to create glibc-hwcaps baselibs as well
- Better filetype detection for temp changes files
- Add hook to run checks after mkbaselibs run
- Delete leftover multilinedefine variable definition
- Support multiline macros in the config's macro sections
- Support #!BuildConstraint lines
- Support #!BuildTarget in spec files to set the build target
  (as workaround of broken BuildArch in rpm since 2001)
- Support a regexp for file renames
- Set home to /root when running build time services
* Fri Nov 18 2022 Adrian Schröter <adrian@suse.de>
- INCOMPATIBLE CHANGE: get rid off the power8 cpu limitation (#889) on powerpc
- Add handling of non-compressed tar when creating Debian archive for DSC 3.0
- Add automatic build-in-place detection
- Support dist/package subdir builds in pbuild
- Skip iothreads on QEMU 7.1.0
- Fix permissions of /dev/pts/ptmx
- Add license to container package list output
- initial SP5 build configurations
- vm-type:qemu use virtio on x86_64
- Improve installation of obs-docker-support for multi-stage builds
- Tweak ARG handling in dockerfile parser
- fixed Undefined subroutine &PBuild::Job::ls issue
- Add missing dependencies from vc as Recommends
* Tue Sep 27 2022 Adrian Schröter <adrian@suse.de>
- fix build of testsuite spec file
* Mon Sep 26 2022 Adrian Schröter <adrian@suse.de>
- sync factory build config
- build-recipe-livebuild: run as root
- vm_kill_kvm: Use SIGKILL after 3 minutes if the kvm process is not going away
- Zip: Allow extraction of symlink targets
- Convert obsolete egrep/fgrep calls to grep -E/-F
- Add RemoteAsset support for Dockerfile based builds
- new image format: mkosi
- Support stacked container builds
- Revert "build-vm-kvm: enable l3-cache on i386/x86_64 builds"
- handling of non-compressed tar when creating Debian archive for DSC 3.0
* Mon Jun 20 2022 Adrian Schröter <adrian@suse.de>
- kvm: exclude powerpc from io_uring, enable iothreads always (#829)
- kvm: enable more performant I/O also for s390(x) (#828)
- Changelog patching when building DSC format 3.0. (#831)
- support for building from slsa provenance files
* Tue May 31 2022 Adrian Schröter <adrian@suse.de>
- Revert "avod aio=io_uring for now on SLE15-SP4 workers"
- deb: defer dpkg triggers until all packages are installed, and disable man-db altogether
- Add support of Debian Source format 3.0 (quilt)
* Fri Apr 29 2022 Adrian Schröter <adrian@suse.de>
- Stop building aarch64_ilp32 baselibs for aarch64
- avod aio=io_uring for now on SLE15-SP4 workers
* Fri Apr 22 2022 Adrian Schröter <adrian@suse.de>
- Update SLE 15 SP4 and Leap 15.4 build config (bsc#1198740)
- Use aio=io_uring if available (bsc#1197699) (build#814)
- Add arm32 and loongarch definitions (build#808)
- Add compatibility code to initvm
- Use upstream way of binfmt argv0 preservation (bsc#1197298) (build#809)
- Add template support for Build::SimpleJSON
- minor documentation updates
* Tue Mar 29 2022 Adrian Schröter <adrian@suse.de>
- docker: Add support for --root and --installroot global zypper options
- debian cross build support via multi-arch (obsoleting cbinstall remnants)
- Tumbleweed config synced
- documentation updates
- smaller bugfixes
* Tue Mar 15 2022 Adrian Schröter <adrian@suse.de>
- regression fix from last release, avoid calling shutdown handler
  twice when building in vm
* Mon Mar 14 2022 Adrian Schröter <adrian@suse.de>
  Changes:
  * pbuild: add --debug option for building debuginfo packages
  * rename --debug to --debuginfo to be more exact.
  * docu: add buildflags:ccachtype and OBS-DoNotAppendProfileToContainername
  Fixes:
  * Avoid shutdown of host when using nspawn
* Mon Mar  7 2022 Adrian Schröter <adrian@suse.de>
  Features:
  * download_assets: add --outdir --clean --show-dir-srcmd5 parameters
    support multiple --arch arguments
  * asset support for golang modules
  * add support for LXC 4.
  * new shortcuts for rpm building:
  - -rpm-noprep, --rpm-build-in-place, --rpm-build-in-place-noprep
    for building directly from upstream git repositories without
    any tar ball.
  * mount securityfs if not mounted by kernel-obs-build
  * collect steal time during VM builds in statistics.
  * declare armv8 and armv7 compatible
  * support OBS Debuginfo build flag for Red Hat variants
  * setup rpmmacros for all build types and earlier
  * Kiwi builds
  - Always append the profile name to kiwi container names
  * Dockerfile build
  - improve registry handling
  - initial Dockerfile.dapper support
  - support 'curl' commands in docker builds
  - strip known domains from container name
  - support container alias names
  * introducing --verbose option, currently only showing kernel
    messages.
  * support cpio creation for special files
  * handle QEMU >= 6.0 on POWER9
  Changes:
  * Use git+https instead of git-https as url schema
  * add oops=panic kernel parameter
  * Updated distribution configurations (esp. Leap 15.4 and Tumbleweed)
  * new preinstallimages are using zstd by default
  * source subdirectories are used in git managed sources
  Minor improvements
  * change sccache default size limit
  * speed up improvements in
  - vm shutdown
  - rpm preinstall
  - avoid calling external commands in a loop
  - using zstd for preinstallimages
  - no more unpacking progress indicators to avoid slowdown
  - virtio handling
  * fixed vm-type=qemu
  * multiple smaller bugfixes and speed improvements
* Thu Nov 25 2021 Adrian Schröter <adrian@suse.de>
- renamed tumbleweed config to tumbleweed
- synced tumbleweed config changes
- initial config for Leap 15.4
- docker build environment
  * Use /.dockerenv as marker for docker environment
  * support privileged docker/nspawn mode
  * move --cap-add=SYS_ADMIN --cap-add=MKNOD to privileged mode
  * initvm: do not attempt to mount /proc and binfmt_misc handler if present
- pbuild
  * rename --hide-timestamps to --no-timestamps
  * reuse options from older builds
  * revised --single build mode
  * support ccache
- Unify ccache and sccache handling
* Mon Oct 25 2021 Adrian Schröter <adrian@suse.de>
  Features:
- deb zstd support (for Ubuntu 21.10)
- support KVM builds with enabled network
- modulemd support improvements
- Support a "Distmacro" directive for recipe parser-only macros
  Fixes:
- Load selinux policy when using a preinstall image
- Use the pax format for preinstall images if bsdtar is available
- Add %%riscv to std_macros
- Fix combine_configs dropping newlines
  pbuild:
- Implement SCC calculation
- Improve --shell-after-build and --single options
- initial documentation of pbuild
- Bugfixes
* Thu Sep  2 2021 Adrian Schröter <adrian@suse.de>
- Fix unpacking of deb/arch archives without bsdtar
* Mon Aug 30 2021 Adrian Schröter <adrian@suse.de>
- fixed regression in multiline macro evaluation from 20th August release
* Fri Aug 20 2021 Adrian Schröter <adrian@suse.de>
  Features:
- cross architecture build support (for rpm and kiwi)
- modulemd meta data support
- pbuild to build multiple source packages
  (initial release, can not be considered stable yet)
- supporting external asset stores for source files
- support multiple post build checks placed in the directory:
  /usr/lib/build/post-build-checks/
- sccache support
- New --shell-after-fail option
- allow to disable squashfs in SimpleImage
- supporting aarch64 kernel on armv?l distributions
- kiwi: Add support for OBS-RemoteAsset and OBS-CopyToImage directives
- container: FROM scratch build support
  Improvements:
- supporting kvm builds as non-root user
- Extend stage selection support for rpm builds
- various distribution config updates
- Support "BuildFlags: cumulaterpms"
  (was done only via suse_version before)
  Fixes:
- container builds
  * support newer podman versions
  * supporting multiple containers for multi-stage builds
- Supporting URL's in Flatpak manifests
- epoch handling in debian builds
- catch more cases where a failed build is marked as host error
- fixing wrong status reporting when a job got killed
- hugetlbfs handling fixes
- try mounting selinuxfs in VM
- Also create the /sys dir when preinstalling (to satisfy dracut)
- various XML parser fixes
- and many minor ones
* Wed Jan 20 2021 Adrian Schröter <adrian@suse.de>
  Features:
- initial flatpak build support added
- ccache support added
- debtransform: Add Debian revision if not present
- allow nodirindex filesystems via BuildFlags: vmfsoptions:nodirindex
- Also do rich dep handling for PreReqs
- kiwi image: configure ndb database if we install the rpm-ndb package
- Implement alternative method to specify build-ignores
  Changes:
- Ignore kiwi-image: deps when expanding image packages
  Fixes:
- Improve autonumbering of source/patch
- init_buildsystem: fix mode of /dev/full
- drop option transparent_hugepages=never on s390x
- Allow --vmdisk-filesystem-options as alias for --vm-disk-filesystem-options
- Do not add a "kiwi-packagemanager:" dependency if no package manager is defined
- debian:
  - Do not leave trailing whitespace while generating .dsc
  - Save modified version into .dsc file
  - Fail `debtransform` test if `debdiff` can't find something
  - return the unmapped arch if it is not found in the mapping hash
  - build-recipe-debootstrap: add fallback for Debian SID distro
* Fri Aug 28 2020 Adrian Schröter <adrian@suse.de>
- support rpmlint installed in /usr/bin/ as well
- fix local build for armv6hl
- Extract generated chart from the tarball instead of using the recipe
* Thu Aug 20 2020 Adrian Schröter <adrian@suse.de>
- fix factory version in config file bsc#1170956
- add missing ignores for Leap 15.2 bsc#1174854
- fix sysrq handling for KVM builds
- avoid double removal of obscpio files
- docker:
  * support builds using USER root statements
  * proper error handling when obs-docker-support gets called as
    non-root
  * helm build target support
  * support milestone handling
- support repo files without types set (SLE 15 SP2 zypp)
- add default substitute for system-packages:repo-creation
- Support recursive kiwi profile usage
* Thu Jul 23 2020 Frank Schreiner <FSchreiner@suse.com>
- fix dependencies for Fedora 33
- Set $YAML::XS::LoadBlessed = 0 for Appimage/Snapcraft
- add a new variable to track build time needed for ccache eviction
- create folder for ccache archive to be copied before rsync
- also package pkg-config files by default into baselibs. (bsc#1172563 etc)
- Use shorter kernel flag for mitigations
- Ignore, if shutdown behavior changed by build in z/VM
- Control disk-space consumption while creating ccache archive
- cleaning ccache
- create folders before trying to copy ccache.tar
- Generate .packages and .basepackages files for docker builds
* Sun May 17 2020 coolo@suse.com
- enable sysrq operations on boot
- Set kvm_serial_device to virtio-serial in the fixup
- Split console arg setting code into kvm_add_console_args
- Update for zVM to make container builds work.
- Write to /proc/sys/kernel/hostname if the hostname command is not available
- Use --cgroup-manager=cgroupfs when calling podman
- Also squash by default in podman builds
- Support different interpreters in prein/postin scriptlets
- Use grep -E instead of egrep to check for the needsbinariesforbuild flag
- Use new Build::Intrepo module
- Add new Intrepo module to read/write build's internal repo format
- remove .gz from _ccache archive as it is no longer compressed
- Add support for Arch in build-recipe-kiwi
- Autodetect whether to use --pipe option of systemd-nspawn.
- Split parse_depfile() from readdeps()
- enable compression on ccache
- add bugzilla numbers for s390 workaround
- extend --ccache to generate _ccache.tar.gz and implement --pkg-ccache
- disable transparent_hugepage on s390x guests for now, causes hangs
- set buildflavor also for Build::parse
* Fri Mar 13 2020 Adrian Schröter <adrian@suse.de>
- Leap 15.2 config update (libzstd1 for rpm)
- handle obscpio extraction error as fatal
- Return correct exit code from systemd-nspawn build
- Spec parser: do not parse included files from end to start
- running disk full check also outside of VM
- run disk full check only for chroot
* Mon Feb 10 2020 Adrian Schröter <adrian@suse.de>
- Spec parser: add support for %%elif, %%elifarch, %%elifos
- Support rpm's %%include statement (EXPERIMENTAL, known limitations)
- Do not do vminstall expansion in expanddeps unless --vm is used
* Wed Feb  5 2020 Adrian Schröter <adrian@suse.de>
- 15.2 config: preinstall gcrypt deps again
- Recommends for Fedora based distros
- support obsgendiff funcationality
- various smaller code cleanups
- additional test cases for spec file parsing
- various fixes for cornercases during spec file parsing
* Fri Jan 31 2020 Adrian Schröter <adrian@suse.de>
- fix regression in && operator handling of rpm spec file parser
- Correctly expand macros defined with %%global
* Wed Jan 29 2020 Adrian Schröter <adrian@suse.de>
- 15.2 config: temporary revert gcrypt preinstall until distro has changed
- factory config: ignore libxtables for iproute2, not needed for ip tool
- Follow upstream rpm changes in regard to logical ops
- Fix macro expansion of lines containing newlines
- add missing header file to avoid compile warnings
* Tue Jan 28 2020 Adrian Schröter <adrian@suse.de>
- support OBS-Milestone comment for kiwi
- switch to preinstall expansion for factory
* Fri Jan 24 2020 Adrian Schröter <adrian@suse.de>
- fix SLE 15 configurations
- Fix dist autodetection for sle15-sp2
* Fri Jan 24 2020 Adrian Schröter <adrian@suse.de>
- Fix crash when using preinstall dependency expansion in OBS
- build-vm-kvm: use /boot/kernel.obs.build and /boot/initrd.obs.build
  as fallback regardless of the platform to have a global fallback
  kernel to use for distros that do not use the "kernel-obs-build"
  package to provide the guests kernel and initrd as the system
  binaries are not reliable for use in a guest system
- use abuild user if $NOROOTFORBUILD is set.
* Wed Jan 22 2020 Adrian Schröter <adrian@suse.de>
- fix createrepo existens check for appimager and docker builds
  in chroot
- support to use virt-make-fs for ext3 VM builds
* Fri Jan 10 2020 Adrian Schröter <adrian@suse.de>
- Arch Linux zstd format support
- fix testbuild fail with latest rpm in SP2 and Leap 15.2
- do not retry automatically on disk full error
* Tue Jan  7 2020 Adrian Schröter <adrian@suse.de>
- allow to enter an existing buildroot w/o recipe
- generate milestone files also for pure online media
- fix ccache setup of non-dotted compiler versions
* Thu Dec  5 2019 Adrian Schröter <adrian@suse.de>
- qemu vm_type is running qemu system emulator now. Works for:
  * aarch64
  * armv7l
  * ppc64/ppc64le
  * s390/s390x
  * riscv64
  Note: this requires a kernel and initrd in build target via
    kernel-obs-build mechanic
- various --shell improvements
- new --shell-cmd to run commands in chroot/KVM/Qemu/... directly
- raising minimal required memory in qemu mode to 512MB to be able
  to run Linux kernel at least
- Normalize epoch 0 away when reading the module info
- Add systemd-nspawn backend (by Oleg Girko)
* Thu Nov 14 2019 Adrian Schröter <adrian@suse.de>
- Add Fedora module parser
- Rpmmd parser: set up a dummy ExternEnt handler
- Add support for modules and publish flags
- add zstd to recommends
- Support rpm's new expression expansion syntax
* Mon Sep 23 2019 Adrian Schröter <adrian@suse.de>
- build-recipe-dsc: Move all build results, not just *.deb and *.changes
- Mount /sys in chroot build
- vc: Do not open the editor if content is set
- adding leap 15.2 and SLE 15 SP2 configs
- Fix some rpmlint warnings
- return exit status 9 in the genbuildreqs case
- Export SYSTEMD_OFFLINE=1 to avoid failures from systemctl
* Tue Jul  9 2019 Adrian Schröter <adrian@suse.de>
- fail build on preinstall failure
- avoid dependency errors on Fedora 30
- fixes for simpleimage vm build support
- support zstd decompression with old rpms
- license tag fixes
* Wed Jun 26 2019 Dominique Leuenberger <dimstar@opensuse.org>
- configs/15.5.conf: add libzstd1 to preinstall list: RPM is being
  extended to support zstd compression, which results in an
  additionaly library being linked in.
* Tue Jun  4 2019 Adrian Schröter <adrian@suse.de>
- configs/15.5.conf: remove brp-extract-appdata from support package
- add "-vv" parameter in case of debbuild
* Thu Mar 21 2019 Adrian Schröter <adrian@suse.de>
- Filter out 'MACRO' from Requires(pre)
- Support createrepo_c's CREATEREPO_CHECKSUMS checksum cache
- Skip unsupported GPG check on ArchLinux
- Support #!BuildRequires dependencies
- Collect more statistics
- Install policy-rc.d to prevent services from starting on Debian
* Wed Jan 23 2019 Adrian Schröter <adrian@suse.de>
- add initial SLE 15 SP1 config (bsc#1122895)
* Mon Jan 21 2019 Adrian Schröter <adrian@suse.de>
- update factory config for libreadline8 switch
- cleanup 15.1 config with OBS specific stuff
  * should not be used for plain build usage
  * workarounds for kiwi should be fixed in packages
* Thu Dec  6 2018 Adrian Schröter <adrian@suse.de>
- support jumping into KVM debug shells using "--vm-type=kvm --shell"
- adapt to new containerd CLI syntax
- Support a new 'UseOBSRepositories' flag
- lxc 3 support
- power9 fixes
- Generate a .milestone artifact for kiwi product builds
- Support rpm's new '^' separator in version comparison
- Allow to specify extra image repos with <!-- OBS-Imagerepo: -->
- Rework release handling of containers
* Mon Nov 26 2018 Max Lin <mlin@suse.com>
- Add Leap 15.1 config
* Mon Oct 22 2018 Adrian Schröter <adrian@suse.de>
- require psmisc util for fuser
- Start debian support for kiwi images/containers
- Support building with unordered repositories for kiwi/docker builds
- Write the package list of the base container in kiwi container builds
- Support kiwi's "additionaltags" attribute (added in kiwi 9.15.3)
- Add some substitutes for the extra container tags
- Support "OBS-AddTag" directive to set multiple container tags in kiwi builds
- Archlinux updates
- SLE 12 SP4 config
- Appimage: support source file parsing
* Wed Aug 29 2018 Adrian Schröter <adrian@suse.de>
- Fall back to $mailaddr if $VC_MAILADDR is unset/null
- don't crash with no rpm macros defined
- Kiwi: support parsing of repos where the .repo file got used
- package hostarch definition in preinstallimages
- avoid double creation of monitor fifo
- Debian:
  - debootstrap: ensure /etc/hosts exists
  - debootstrap: Add abuild shadow password entry
  - livebuild: publish source tarball
  - Adds Debian configurations for jessie and unstable
  - collect *.ddeb, *.udeb files
* Thu Aug 16 2018 adrian@suse.de
- docker format: New podman/buildah build engine support
- Support for full names in changes files
- Set %%url macro when seeing an Url:
- pacman CLI updates
- enable core dump generation in VM builds
- Disable kpti on guest kernel for performance and correctness
- support for e2fsprogs 1.43.1 with old kernels
* Fri Jun 29 2018 FSchreiner@suse.com
- docker:
  * use a correct prefixed label for disturl
  * Support building multiple image types containing a docker image
  * Set build user to root for docker/fissile builds
  * Compress containers so that old kiwi versions can handle them
  * Put obs-docker-support uninstall before the last user line
  * Also pass arch and buildflavor when creating the containerinfo
  * set disturl as container LABEL
  * Uncompress kiwi generated containers
  * build-vm-docker: type=bind instead of type=volume in --mount option
- computeblocklists/extractbuild:
  * Tweak verbose logging of directories in computeblocklists/extractbuild
  * add support for FIEMAP ioctl
  * don't use bare F for file
  * document and use alternate ioctl numbers
  * more tweaks and sanity checks
  * Fallback to encode/decode helpers if perl does not support 'Q' in pack/unpack
  * Use 'eval' when querying the blocklist
- Misc:
  * fix escaping in regexp
  * log toplevel KIWI directories in verbose mode
  * Split kiwi product parser in a separate function
  * Always add extra dependencies when doing sysdeps expansion
  * Fix REPOTYPE setting if the PKGCONFIG file is generated by a service
  * support zypper's handling of versioned deps
  * pam-modules got dropped on sles 15
  * testing for build specific filesystem, which are more important then worker defaults
  * mark lint option as obsolete
  * Make sure that we know all pre/vminstalls
* Tue Apr  3 2018 adrian@suse.de
- KIWI: Support OBS-Profiles kiwi annotation
    kiwi profile filtering
- Switch to a little perl http server to get rid of the python2 dependency
- Avoid Ubuntu 18.04 uncompress failure messages
- Don't rely on AppImage's auto-detection for architecture
- build-recipe-livebuild: count ONIE images as build results
* Fri Feb  9 2018 adrian@suse.de
- add sysrq functionality for KVM builds
- add initial SLES 15 config
* Wed Jan 31 2018 adrian@suse.de
- add own baselibs config for SLE 11
* Wed Jan 24 2018 adrian@suse.de
- Fix picking of right changes file for changelog generation (boo#1077145)
* Tue Nov 28 2017 adrian@suse.de
- Fixed Dockerfile repository parsing
- Improve file name check extractbuild (CVE-2017-14804, bsc#1069904)
- track release number of containers
- Define SOURCEURL and PATCHURL macros
- Keep preinstalled packages
- add libidn2 and libunistring to preinstall for archlinux
* Tue Nov 21 2017 coolo@suse.com
- buildignore the sle flavor of mkbaselibs for sle
* Fri Nov 17 2017 adrian@suse.de
- prepare for suse_version 1550 in factory (by Dominique)
* Thu Nov  9 2017 adrian@suse.de
- fixes syntax error fissile support
- various container handling improvements
- support new debian control.tar.xz files
* Thu Oct 12 2017 adrian@suse.de
- proper fix for for liblua, for factory and leap 15.0
* Thu Sep 21 2017 coolo@suse.com
- Support getting the container tags from the Dockerfile
- Put the disturl in the .buildenv file
- Support rpm-buildroot-override buildflag
- Support kvm builds on Debian
- Support with/without/unless rich deps
- Added obs-docker-support script for docker images
- Initial SLE 15 config
* Wed Aug  2 2017 lnussel@suse.de
- Temporary hack to aid liblua5_3 -> liblua5_3-5 rename
* Thu Jul 20 2017 mls@suse.de
- switch baselibs scheme for debuginfo packages from
  foo-debuginfo-32bit to foo-32bit-debuginfo [fate#323217]
* Fri Mar 17 2017 adrian@suse.de
- fix usage of the right service generated files.
- debootstrap: Also mount sysfs
- Fileprovides should only match package names, not provides
- avoid export of build results of sym links pointing to external files
- support build of different flavors via multibuild
- experimental AppImage build support
- reworked openstack support (still experimental)
* Thu Feb  9 2017 adrian@suse.de
- updated confguration for tumbleweed
- Arch linux fixes
- mount swap by label
- allow custom qemu options
- allow to override hostname
- fix build with vm-type lxc
* Wed Jan 25 2017 adrian@suse.de
- fix haskell builds (bsc#1018895)
- fix multi type kiwi profile handling
- minor distribution config and bug fixes
* Tue Dec  6 2016 adrian@suse.de
- add config for openSUSE Leap 42.3 (alpha, non-final)
- handle Fedora 25 special cases
- Improve /proc mount behaviour
- fix dependency on CentOS (build#2415)
- Use weak dependencies as 3rd choice breaker
- support statistics from xvda devices
- build env wipe support (--wipe command)
* Tue Nov 29 2016 adrian@suse.de
- speed up build (for preinstall and keeping packages)
- Recognize Recommends and Supplements relations of RPMs.
- fix build against susetags repos
* Tue Oct 25 2016 adrian@suse.de
- Add clang binaries to ccache symlinking
- Fix a probable tabs to spaces bug
- Kiwi: allow to specify ExclusiveArch and ExcludeArch
- build-vm-kvm: use virtio-rng-device also on aarch64
- Add support for LXC as libvirt driver
- support multiple image builds for multiple profiles
- Add optional whitelisting for allowed buildroots and parameters
- build-vm-xen: use xvd devices for disks and hvc0 for console for recent xen
- build-vm-kvm: fix vm_enable_console also for kvm_serial_console case
- sl13.3.conf: Prepare for bash 4.4, using libreadline7
- Add and clarify licenses
* Wed Aug 10 2016 lnussel@suse.de
- calculate leap version for default config
* Tue Aug  9 2016 adrian@suse.de
- first version of Leap 42.2 configuration
- provide loop devices in docker VM
- support lxc 2.0
- Add architecture-specific sources extract for Arch Linux
- snapcraft improvements
* Thu Jun 30 2016 adrian@suse.de
- adding first snapcraft support
* Wed Apr 27 2016 adrian@suse.de
- fix build on armv7hl
* Wed Apr 27 2016 adrian@suse.de
- run debtransform after buildtime source services
- Handle also aarch32* and armv8 cases for kvm cpu switches
- add support for LXC 1.0.8
- added DoD for aarch64 repositories on Debian
* Fri Apr  8 2016 adrian@suse.de
- support unpacking of obscpio archives in source
- added DoD for aarch64 repositories on Debian
- aarch64_ilp32 support
- KVM: telnet feature fixes and documentation
- KVM: run qemu as user
- fail when space allocation is not successful (on supported FS)
* Fri Mar  4 2016 adrian@suse.de
- add switch to enable VM console input
- add --vm-user option to run kvm as non-root
- Implement experimental obscpio unpacking
- Use fallocate -p for a fast zero-fill, correctly truncate.
- PowerVM backend
- Make --ignoreignore only ignore ignores from the project config
- aggregate patches fields
- Fail simpleimage build when integration scripts fail
- mkdrpms: do not create debuginfo/source deltas
  Kiwi:
- Support new Kiwi v8 (experimental)
- Make sure kiwi is called in UTF-8 locale
- Kiwi appliance: support "replaces" attribute and handle it as buildignore
- KIWI profile support
- Support a way to map urls to OBS project/repos
  Debian:
- Support lintian when OBS_DCH_RELEASE set
- Add support for debbuild's eval and .debmacros
* Thu Nov  5 2015 adrian@suse.de
- add openSUSE 42.1 config (bnc#953782)
- avoid full path in sha256 files of products
- support virtio-rng device in kvm builds
- lxc 1.1 support
* Fri Oct  9 2015 adrian@suse.de
- avoid dependency to perl(parent) again
- fixed buildtime source service execution
- fixed debian collax support
* Thu Sep 17 2015 adrian@suse.de
- collax support added
- Fix auto-detection of -p1 option to patch
- Handle .deb files that have sysv ar(1) filenames
- Exported RECIPEFILE in build-recipe-livebuild
* Wed Sep  2 2015 adrian@suse.de
- openSUSE 13.3 config added (bnc#944121)
- Support old versions of Archive::Tar
- debtransformer xz archive support
- workaround for broken chroot command (Mageia:5 shipped with it)
- Support building with Mandriva/Mageia Repositories
- debian: Various bugfixes for lintian support
- debian: Generate .changes files when building deb packages.
- create /dev/loop-control for kernel >= 3.1
- support singleexport flag handling
- Fix precedence of unary '-' and '!'
- fix ppc qemu registration rules
* Wed Jun 17 2015 adrian@suse.de
- fixing test suite call
* Mon Jun 15 2015 adrian@suse.de
- support build time source services
- docker VM support
- Simple image creation support
- vc: create changelog file only in case of a change
- get hostarch based on preinstalled kernel image
- architecture CanDo updates
- avoid endless loops during in binfmt misc registration
- debian debootstrap fixes
- added support of debbuild build engine
- optional support of network inside of KVM
- allow lintian to break the build
* Tue Mar 17 2015 adrian@suse.de
- workaround initrd breakage when using initrd for systemd with older systems
- fixes for building in LXC containers
- avoid emulator for arm on aarch64
- Fixing UTC symlink resolving when setting localtime
- ppc64le can build ppc64 with KVM
- build-vm-kvm: Switch armv7 to virt machine
- Fix --no-checks with older rpmbuild
- documenation updates
* Fri Jan 30 2015 adrian@suse.de
- add recommend to perl(Net::SSL) (bnc#880212)
- add support for debian debootstrap build engine
- Update arch config
- Add support for conflicts, addselfprovides, weakdeps to query functions
- installed package handling works also for arch and debian now
- large code cleanup
- bugfixes and documentation updates
* Mon Nov 24 2014 adrian@suse.de
- Add releasesuffix hack for new PTF handling
- support parallel build jobs for debs
- Fix repocfg usage in the "exact match" case
- Improve exclarch handling for deb builds
- rewritten workaround for broken chroot tool
* Mon Oct 27 2014 adrian@suse.de
- add support for new chroot tool
  * fixes Ubuntu 14.10 builds
- man pages for unrpm and vc
* Fri Sep 19 2014 adrian@suse.de
- drop not available packages from SLE 12 config
* Thu Sep 18 2014 adrian@suse.de
- fix syntax error in SLE 12 config
* Tue Sep 16 2014 adrian@suse.de
- add SLE 12 config (bnc#893618)
- build-vm-kvm: Always use -mem-prealloc when using -mem-path
- debian livebuild support
- various ppc handling fixes
- various smaller fixes
* Thu Apr 24 2014 adrian@suse.de
- build script got refactored and split in multiple modules
* Thu Feb 20 2014 adrian@suse.de
- bugfix release
  - /sys mounting
  - binfmtmisc setup
* Thu Dec  5 2013 adrian@suse.de
- fix ppc64le vs. ppc64 emulator check (none needed)
* Thu Dec  5 2013 adrian@suse.de
- fix vc tool regression from "minor fixes"
* Wed Dec  4 2013 adrian@suse.de
- support for project side configured VM kernels
- ppc64le support
- minor fixes
* Tue Oct 15 2013 adrian@suse.de
- update openSUSE 13.1 build configuration
- add openSUSE 13.2 build configuration
- add support for m86k
- add support for Tizen changelog date format
- export .packages, .verified and .ova files for kiwi
- initvm code cleanup
- Do not specify compression format for Arch packages when extracting
- export kiwi-image:$type for kiwi files with schemaversion 5.6 or newer
- mount tmpfs on $BUILD_ROOT/dev/shm
- Create devices nodes if udev is not running
- more arm architectures
- make version '0' a valid version
- fix the call to lintian, lintian gets a dsc file as input
- adding generic parameter to hand over kiwi parameters
* Fri Aug  2 2013 dvlaeev@suse.com
- add requires for Fedora
* Fri May 17 2013 adrian@suse.de
- fix build for non-SUSE rpm distros
* Fri May 17 2013 adrian@suse.de
- fix a number of issues regarding statistics collection
  => works with more udev versions now
* Wed May 15 2013 adrian@suse.de
- fix qemu-binfmt registration in chroot builds
* Tue May 14 2013 adrian@suse.de
- debian builds call linitian now if installed
- Arch Linux: support new pacman tool syntax
- support kiwi installation medias with new kiwi versions
- fixed regression using build host rpm instead of the version from chroot
- fixed repository priority ordering, when only some repos have a priority
  and kiwi appliances get build
* Wed May  8 2013 adrian@suse.de
- support multi architecture initvm binaries
  => vminit gets build as subpackage now again
- De-hardcode hugetlbfs from ppc
- Do not emulate VGA
- support new nameing scheme of install images of kiwi builds
* Mon Apr 29 2013 adrian@suse.de
- disabling fsync again for newer rpm versions to speed up
  installation phase again.
* Fri Apr 26 2013 adrian@suse.de
- cloud support for Amanzon EC2 and openstack
- fixed SPEC_REL support
- fixed zvm build
- fixed uml support
- fixing ext4 usage on old distros
- final openSUSE 12.3 config
- arm build support fixes
* Tue Apr  2 2013 coolo@suse.com
- add sl13.1.conf (openSUSE:Factory prjconf of 2013-03-29)
- have ncurses-devel-32bit require ncurses-devel and not ncurses-32bit
- do not put .socket files into the 32bit packages
- unbreak kvm for x86_64
* Fri Mar  8 2013 adrian@suse.de
- fix kvm support for x86_64 again
* Mon Mar  4 2013 adrian@suse.de
- avoid writing out incomplete IO statistics
* Wed Feb 27 2013 adrian@suse.de
- ARM AArch64 support added
- Generic system emulator support as VM added
- s390 z/VM build environment support added
- support collecting resource statistics during build (for OBS 2.4)
- rpm5 fixes
- kvm support for armv7l
- mount /dev/pts with right permissions
* Mon Nov 26 2012 adrian@suse.de
- fixed deb building
- collecting statistics during VM build
* Fri Oct  5 2012 adrian@suse.de
- backport /proc mounting for rpmlint for factory
* Thu Sep 27 2012 coolo@suse.com
- change to automatic date version in _service
- update from git (4afd9f0ee03f9e51cf8db9a27fae4663e3f4dde6)
  Martin Koegler (1):
    Bug fix: ignore links in orig tar files
  Michael Schroeder (1):
  - be more verbose when the preinstallimage unpack fails
  Stephan Kulow (2):
    the difference between openSUSE and SLE is outdated
    do not cumulate packages with 12.2's rpm
* Tue Sep 25 2012 coolo@suse.com
- remove build-mkbaselibs-sle, the split is no longer necessary
- remove default requires for devel-32bit
* Tue Sep 25 2012 coolo@suse.com
- fix logic for cumulating packages
* Mon Sep 24 2012 coolo@suse.com
- update to current git (03587016a7eca7788f404820642a2b5a1556aa0b)
  Adrian Schröter (1):
  - use default MEMSIZE in check_for_ppc
  Anas Nashif (2):
    pass --use-system-qemu option to init_buildsystem
    Support https repositories
  Frank Lichtenheld (1):
    init_buildsystem: fail early on reorder failure
  Martin Koegler (4):
    Diff can't handle empty files
    Refactor diff generation
    Handle overriden files already present in the orig.tar.gz correctly in debtransform
    Correct version number of binaries, if necessary
  Michael Schroeder (3):
  - don't add self-provides for src packages
  - support binary rpms with fo SOURCERPM header element
  - drop '-o' bsdtar flag when unpacking preinstall images
  Werner Fink (1):
    Make init_buildsystem able to use the features of newer rpm
* Fri Aug 24 2012 mls@suse.de
- update to current git
  * fixed arch PKGBUILD parsing
  * add .qcow2 file handling for kiwi
  * support root tar ball output format of kiwi
* Tue Aug 21 2012 adrian@suse.de
- update to current git
  * fixed cross build initialsation with chroot
  * ignore prereqs for subpacks to be built
  * more Arch Linux support
  * new --vmdisk-clean switch
- add recommends to qemu-linux-user
* Thu Jul 19 2012 adrian@suse.de
- update openSUSE 12.2 config to RC1 state
- add openSUSE 12.3 config to fix build for factory
- do not package compressed _and_ uncompressed kiwi images
- add build timestamps in each logfile line
* Mon Jul  2 2012 adrian@suse.de
- preinstallimage support added
* Thu Jun 14 2012 adrian@suse.de
- build fixes for Fedora 17
- syntax error fix for kiwi vmx builds
* Tue Jun  5 2012 coolo@suse.com
- update from git:
  (mls) simplify debug package code so that it also works with --target
* Thu May 31 2012 adrian@suse.de
- take care of prjconf target: definition for spec file parsing
* Wed May 30 2012 adrian@suse.de
- support for breakages in Fedora:17
  * support enforced ordering during preinstall and vminstall phase
  * allow to extract files via symlinked directories
* Mon May 14 2012 coolo@suse.com
- work around command line size limit
  mkbaselibs may fail on an excessive number of packages (bnc#761977)
- improve build root owner setting
- don't die at compile time if Archive::Tar is not available
* Tue Apr 24 2012 adrian@suse.de
- fixed breakage with older perls
- ~ support for rpm version compare
- handle broken deb packages better
- no more hardcoded copy-in of qemu* binaries
* Mon Apr 23 2012 adrian@suse.de
- do not use sle-baselibs.conf on openSUSE
* Tue Apr 17 2012 cfarrell@suse.com
- license update: GPL-2.0+ and GPL-2.0
  See e.g. spec2changelog by Pascal Bleser. Also, there should be a copy of
  the GPL-2.0 license in the package
* Wed Mar  7 2012 adrian@suse.de
- check_emulator needs to use $BUILD_DIR for initvm checks or obs
  worker builds may break
- Introduce --vmdisk-mount-options
* Wed Feb 29 2012 adrian@suse.de
- using xz compression for kiwi raw files
- progress counters during installing
- 12.2 config added
* Mon Feb 13 2012 adrian@suse.de
- Support for openSUSE 12.2 (current factory)
- Support for crossbuild via Hostarch directive
- PPC KVM support
- swap space gets taken into account for ulimits
- Failure on not supported personality set
* Tue Oct 25 2011 adrian@suse.de
- use github.com as git repo now
- fix build for rpmv5
* Mon Oct 10 2011 mls@suse.de
- add sles11sp2 build config and adapt autodetection [bnc#711770]
* Tue Oct  4 2011 adrian@suse.de
- use new qemu-*-binfmt handler to run commands with correct $0
- fix build for Factory
* Mon Sep 26 2011 adrian@suse.de
- fixing kvm cpuid setting for AMD and Intel CPU's
- support new xen tools
- fixed qemu build initialisation
* Sun Aug  7 2011 opensuse@cboltz.de
- Requires:/Recommends: were part of the package description.
  Moved them to the correct place.
* Fri Jul  1 2011 adrian@suse.de
- compat mode for broken kiwi of openSUSE 11.4
* Thu Jun 30 2011 adrian@suse.de
- fixed kiwi execution call for some versions
* Fri Jun 17 2011 adrian@suse.de
- support new kiwi command line mode
* Mon Jun  6 2011 adrian@suse.de
- do not build ia64 baselibs packages for openSUSE anymore
* Wed May 25 2011 adrian@suse.de
- allow to use simple spec file parser via Build::show
* Thu May 12 2011 adrian@suse.de
- conflict with old bsdtar (not supporting --chroot)
* Wed Apr 27 2011 adrian@suse.de
- revert to single cpu build default for debian packages
* Fri Apr 15 2011 adrian@suse.de
- switch back to single process build for debian to be conform with
  their policy
- use cpuid kvm64 on kvm for 64bit as workaround for a cpuid bug
* Tue Mar 29 2011 lnussel@suse.de
- make sure default.conf is no stale symlink
* Tue Mar  1 2011 adrian@suse.de
- support new cross build initvm. Done by James Perkins from LinuxFoundation
- do not use loop device anymore when using block devices directly
* Thu Jan 20 2011 lnussel@suse.de
- force use of bsdtar for VMs (bnc#665768, CVE-2010-4226)
* Thu Nov 11 2010 adrian@suse.de
- workaround for distros with appstart like Ubuntu 10.10
* Tue Nov  2 2010 lnussel@suse.de
- delta size limit 80%%
- actually unlink the delta file if the delta is too big
* Wed Oct 27 2010 lnussel@suse.de
- use '.drpm' suffix instead of '.delta.rpm' for delta rpms
- makedeltarpms -> mkdrpms and also rename subpackage to match
  script name
- since mkdrpms needs Build.pm make perl-TimeDate dependency of
  build optional
* Mon Oct 18 2010 lnussel@suse.de
- add missing optional perl dependencies
* Fri Oct 15 2010 adrian@suse.de
- update to current git
  * export also fallback archs as exclusive archs for kiwi product
    building, fixes factory dvd5 64bit media
  * cross build fixes by Martin Mohring
  * correct disk image file creation, it was one byte too large by James Perkins
* Tue Sep 21 2010 adrian@suse.de
- update to current git
  * workaround for supporting rpm install on cross build with native
    acceleration
* Mon Sep 20 2010 lnussel@suse.de
- package mkdrpms script in separate package
* Tue Aug 24 2010 adrian@suse.de
- update to current git
  * support for mips cross build
* Wed Aug  4 2010 adrian@suse.de
- update to current git
  * replace release number macros with 0 if not specified
* Wed Jul 28 2010 mls@suse.de
- update to current git
  * document --repo and --dist
  * update wiki links
  * fix bugs in repo handling
  * fix distribution autodetection code
* Thu Jul 22 2010 adrian@suse.de
- update to current git
  * support for Files provide
* Thu Jul  8 2010 adrian@suse.de
- update to current git
  * export BUILD_DEBUG so rpmlint can check for it (bnc#618004)
* Tue Jun 29 2010 mls@suse.de
- update to current git
  * add 11.3 config
  * fix repo creation in --noinit case
  * support ovf files directly
  * allow multiple --oldpackages
  * delta rpm support
* Mon Jun 21 2010 adrian@suse.de
- update to current git
  * fixes for image building for SLE 10
  * fix parsing of macros that contain {} blocks
  * support xz decoder helper script
  * don't substitute in lines with %%(), the parser cannot handle it (bnc#613965)
  * run kvm instance with the right number of cpus according to given parallel build jobs
* Sat May 29 2010 adrian@suse.de
- update to current git
  * noatime VM mount
  * _service file rename happens inside of chroot/vm now.
* Tue May  4 2010 adrian@suse.de
- update to current git
  * CBinstall and CBPreninstall directive support from Jan-Simon
* Wed Apr 21 2010 adrian@suse.de
- detect kvm virtio initrds on SUSE systems automatically
* Sun Apr 18 2010 ro@suse.de
- build-mkbaselibs: also move baselibs*conf to subpackage
* Thu Apr 15 2010 ro@suse.de
- add BuildIgnore build-mkbaselibs to be able to bootstrap
* Thu Apr 15 2010 adrian@suse.de
- split out -mkbaselibs package to avoid build dependency problems
  on perl version updates in future.
- update to current git
  * added armv6el to emulator archs by Jan-Simon.
  * fixing a logic error in arch= attribute handling for kiwi
* Fri Apr  9 2010 adrian@suse.de
- update to current git
  * Support for remote yum repos by yi.y.yang@intel.com
  * fixed kiwi file parsing for arch= attributes
* Wed Mar 31 2010 adrian@suse.de
- update to current git
  * kvm autosetup enhancements
  * multiple bugfixes and refactoring
* Wed Mar 10 2010 adrian@suse.de
- update to current git
  * Kiwi exclude arch handling
* Mon Mar  8 2010 adrian@suse.de
- create default.conf symlink to correct *.conf based on
  %%suse_version and %%sles_version macros
* Thu Feb 25 2010 adrian@suse.de
- add dependency to tar (needed for deb builds)
- use current git
  * Added '--uid uid:gid' feature to specify abuild id in chroot
    (by David Greaves)
* Sat Feb 20 2010 adrian@suse.de
- update to current git
  * fix for permissions for debian (done by Jan-Simon)
* Thu Feb 11 2010 adrian@suse.de
- update to current git
  * fixed handling of kiwi build results
* Mon Feb  8 2010 adrian@suse.de
- update to current git
  * support kiwi 4.1 schema files
* Tue Jan 19 2010 adrian@suse.de
- update to current git
  * fixed missing --root parameter for substitutedeps call
* Mon Jan 18 2010 adrian@suse.de
- update to current git
  * create .sha256 files for kiwi image results
* Wed Jan 13 2010 adrian@suse.de
- update to current git repo
  * unbreaking kiwi builds again
* Sun Jan  3 2010 adrian@suse.de
- update to current git repo, update to commit 549cf6c6e148b7f8c05c12ee06f3094cb67149f9
  * minor bugfixes
  * sparc support fixes
* Thu Dec 10 2009 adrian@suse.de
- switch to git repository, update to commit c8b33e430bfb40b80df43249279bd561d874d786
  * product building via abuild user
  * prodoct building speedup
* Fri Nov 27 2009 adrian@suse.de
- update to svn(r9279)
  Debian packages get configured at install time  again now.
  But keeping additional configuration step afterwards for failed
  configutions (due to dep cycles)
* Fri Nov 27 2009 adrian@suse.de
- add requires to perl-TimeDate for changelog2spec app
* Wed Nov 25 2009 adrian@suse.de
- update to svn(r9238)
  * Debian chroot enviroments are running post installation scripts
    now after all packages got installed, not after each installation
    (partly fixes Ubuntu 9.10 setup)
* Sat Nov 21 2009 adrian@suse.de
- update to current svn(r9154)
  * add support for xz compressed rpms (Fedora 12) on platforms without xz support in
    rpm.
  * speed up install by disabling fsync in rpm config
* Thu Nov  5 2009 adrian@suse.de
- update to current svn (r8506)
  - product iso generation is done by kiwi now
  - debs get generated via "make install"
* Wed Sep 23 2009 mls@suse.de
- update to current svn (r8048)
  - support openSUSE 11.2 [bnc#539914]
* Mon Jul 27 2009 ro@suse.de
- update to current svn (r7751)
  - support for legacy releasepkg mechanism
  - only print parse warnings if $config->{'warnings'} is set
  - set warnings for expanddeps/substitutedeps
  - use UTC as default timezone
  - also consider patches as sources
  - do not call depmod until we use also the native kernel,
    it can't match otherwise
  - return with value 3, if basic file system creation fails.
    bs_worker will mark the build host as bad and retries on another one.
  - handle files from service correctly and strip their prefix.
  - - also add rpmv3 compatibility hack to createrpmdeps
  - mount proc filesystem for build compare run
  - fix for ccache support from
  - add build-ids for debuginfo packages for subpacks
* Wed Jun  3 2009 adrian@suse.de
- update to current svn (r7483)
  * Jan-Simons "ChangeTarget" support
  * fix for handling missing self provides with rpm format 3.0.6
* Thu Apr 23 2009 adrian@suse.de
- update to current svn (r7164)
  * package vc tool correctly
  * avoid running fsck on vm instances after 23 build runs
- install files via Makefile instead of manual calls in spec file
* Mon Apr 20 2009 adrian@suse.de
- update to current svn (r7126)
  * new blocklist based build result export
  * Martin Mohrings cross build extensions
  * vc tool included now
* Mon Mar 23 2009 adrian@suse.de
- Fix for "Requires(pre/post)" tags
- fix missing abuild group in /etc/gshadow on debian like distros
* Wed Feb 25 2009 adrian@suse.de
- Update for bug fix for image build with additional packages in --create step
  (fix from cthiel, bnc#479537)
* Fri Feb 20 2009 adrian@suse.de
- Fix kvm support together with Alexander
- Support for new disturl containing a complete pointer to build
  service instance resource
- add support for package compare to allow Build Service to drop
  same packages after build
- image repack support from Christoph
* Tue Jan 27 2009 adrian@suse.de
- update to current buildservice/1.5 branch
- More fixes for kiwi image build
- Move Susetags.pm to correct Build:: namespace
* Wed Dec 10 2008 froh@suse.de
- update to r5853:
- added: new armv7el arch for all binaries for up to ARMv7 EABI with VFP
- Fix kiwi image build support within osc
* Fri Dec  5 2008 froh@suse.de
- remove baselibs.conf from the spec file, too
* Fri Dec  5 2008 ro@suse.de
- delete baselibs.conf (nowadays stored in package sources)
* Wed Dec  3 2008 ro@suse.de
- delete automatic requires for debuginfo-xxbit
* Wed Dec  3 2008 froh@suse.de
- config update
* Fri Nov 28 2008 froh@suse.de
- many kiwi fixes
- _no_ cross build support yet
* Thu Nov 13 2008 ro@suse.de
- update mkbaselibs broken by previous debuginfo change
- various fixes for kiwi build
- add sl11.1.conf
- add support for --disturl
- also save .desktopfiles for coolo
* Thu Oct 23 2008 ro@suse.de
- disable ppc:ia32 stuff again, causes trouble and can not work
* Tue Oct 21 2008 jblunck@suse.de
- Generate debuginfo packages for baselibs (bnc #396196)
* Mon Oct 20 2008 ro@suse.de
- update to svn trunk of today:
- init_buildsystem: check for some left space before calling rpmbuild
  - create dev/shm as directory
- baselibs_global.conf: update to current internal revision
  - add ia32 stuff for x86 binaries on ppc
  - add ldconfig for all non-devel baselibs packages
- changed: to function also with emulators better use fakeroot-tcp
  for debian build
- fixed: changed basis for memory calculation to assume also a stack
  which can be swapped well. gcc often needs much memory here
- recognize SLES10
- fix boolification in && and ||
- re-preinstall critical packages on update
- fix creation of buildenv to do it the same time with and without VM.
- fixes installation-images build for ppc
- fixed #406596: don't ignore BuildRequires in subpackages
- print finished message
- set BUILD_USER depending on the suse_version like it is done in
  old autobuild
- added documentation for specfile control comments for build(1)
- add --incarnation
- add --create-build-binaries
- support badarch (aka excludearch)
- add support for Requires(pre) or (post) semantic
* Mon Aug 11 2008 adrian@suse.de
  Update from current svn trunk:
- Improved XEN support (XEN call only once per build)
- Add post build check hooks
- rpmlint support
- added kvm support
- refactored code in various places
* Tue Jun  3 2008 mls@suse.de
- fix debtransform bug [bnc#396766]
* Thu May 29 2008 mls@suse.de
- add 11.0 config
- fix debian provides
- fix rpm tag parsing
- add with/without/define/ccache/icecream/debug options
- update mkbaselibs
* Fri Sep 14 2007 mls@suse.de
- add sl10.3 config [#310089]
- also look for BuildRequires in subpackage definitions [#305568]
- allow removal of more config parameters
* Thu Aug  2 2007 mls@suse.de
- support 'order' config option
- support 'patterntype' config option
- new setdeps() method
- support for flexible query options
- support 'description' query
- fix bug in changelog2spec time cutoff
- make debtransform understand Debtransform-Tar/Debtransform-Files-Tar/
  Debtransform-Series
- fix bug in substitutedeps
* Wed Jun 13 2007 mls@suse.de
- implement rpm installation order calculation in perl
- make substitute code modify requires, too
- add filelist query support
- add prereq parsing support
- speed up version comparison a bit
* Thu May 10 2007 mls@suse.de
- add _vendor to configs
- fix deban dependency compare
- allow not operator in configs
- fix build from source rpms
* Thu Apr 12 2007 mls@suse.de
- add --root to rpm call in rpm to work around a bug in rpm [#255720]
* Thu Apr  5 2007 mls@suse.de
- update to 1561:
  * support architecture dependand requires in dsc files
  * support "global" definitions for rpm
  * support vminstall config option
* Mon Mar 12 2007 mls@suse.de
- update to r1419:
  * fix buildroot in debtransform
  * obey version numbers when expanding
* Fri Mar  2 2007 mls@suse.de
- transform suse changes file to rpm specfile format
- improved debian support
* Fri Jan 26 2007 poeml@suse.de
- update to r1114:
  - re-add the lost unrpm script
* Fri Jan 26 2007 poeml@suse.de
- update to r1110:
  - make exclarch an array
  - remount root rw in xen case, needed if root is not reiserfs
  - add repotype/runscripts options
  - remove devs in sl10.1/10.2
  - fix boolean test to make "00" false like rpm does
  - add rpm_verscmp for version comparison
  - runscripts
  - macro blocks
  - read_config_dist
  - useful xen exit status
  - add --kill
  - update 10.2 config
  - extend spec/dsc parser
  - fixed two bugs in the specfile parser
* Fri Nov 24 2006 mls@suse.de
- fix suse_version in sl10.1/sles10 config
- add sl10.2 config
- make dist autodetection work with opensuse
- fix macro sequencing and expression parser bugs
- treat preinstalls as keep
* Wed Aug 23 2006 ro@suse.de
- init_buildsystem: when preinstalling, handle only sh scripts
* Wed Jun 14 2006 mls@suse.de
- support for buildservice and debian packages
* Fri Apr 28 2006 mls@suse.de
- add ndeps back to expansion calls
- save original macro name so that other regexp calls don't destroy
  it
* Wed Apr 19 2006 mls@suse.de
- add --list-state option [#119869]
- suppress stat messages when deleting rpms [#154385]
- delete not-ready flag when rpm expansion failes [#133568]
- update baselibs.conf
* Tue Apr 11 2006 mls@suse.de
- fix typo in configs
- fix macro handling
* Fri Apr  7 2006 mls@suse.de
- mkbaselibs: do not leave .src.rpm in the release [#158816]
* Tue Apr  4 2006 mls@suse.de
- add update-alternatives to java2-devel-packages macro [#156137]
* Mon Mar 27 2006 mls@suse.de
- run zic to set default timezone [#142363]
- update baselibs.conf
* Fri Mar 24 2006 mls@suse.de
- fix handling of "keep" [#160346]
- fix old configs [#159947]
* Mon Mar 20 2006 mls@suse.de
- make mkbaselibs use the right version for the srcrpm
- update mkbaselibs configuration files
* Fri Mar 10 2006 mls@suse.de
- add package expansion and dependency substitution support
* Wed Feb  8 2006 agruen@suse.de
- Adjust the package lists so that the build script can at least
  be used again.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 12 2005 mls@suse.de
- also search for ix86 packages when building x86_64 [#116069]
* Mon Sep  5 2005 mls@suse.de
- add --baselibs option
- fix --extra-packs
* Thu May 12 2005 mls@suse.de
- Fix typo in init_buildsystem that prevented the reuse of the build
  environment [#74714]
* Fri Mar 11 2005 mls@suse.de
- integrated patches into tarball
- allowed build for older dists [#65506]
* Wed Mar  2 2005 agruen@suse.de
- Some more cleanups for 9.3.
- When using the default list of packages, also try to include the
  packages in neededforbuild.
* Mon Feb 28 2005 agruen@suse.de
- ldconfig must be called with its absolute path.
* Tue May 25 2004 mls@suse.de
- overhaul the manpage
* Thu Mar 25 2004 mls@suse.de
- incorporate ro's diff
* Wed Mar 24 2004 mls@suse.de
- really adapt to 9.1
- add --root and --extra-packs options
- use BuildRequires: line
- use user 'abuild' if norootforbuild found
- fix BUILD_DIR security issue (#35281)
* Thu Mar 11 2004 ro@suse.de
- adapted for 9.1
* Mon Nov 10 2003 mmj@suse.de
- Accept "-h" for help
- rpm -ba is now rpmbuild -ba
- Add Maximum RPM reference
* Mon Nov 10 2003 mmj@suse.de
- Update the default USEDFORBUILD to match todays packages
- Don't build as root
* Wed Oct 15 2003 mmj@suse.de
- Fix to work on amd64 (from mls) [#32229]
* Fri Sep  5 2003 mls@suse.de
- select i586 on i686 is user didn't specify arch
- complain if user wan't to build i686 on a not-i686 processor
- patch rpmrc so that i686 rpms are written if building for i686
* Thu Sep  4 2003 mls@suse.de
- port to sl90
- allow path for BUILD_RPMS
- add BUILD_ARCH and autodetection
- add --jobs and --target options
* Fri Aug 29 2003 nashif@suse.de
- fixed call for "head"
* Thu Aug  7 2003 schwab@suse.de
- Fix typo.
* Thu Aug  7 2003 mmj@suse.de
- Enhance build.1 a bit
* Sat Mar  8 2003 kukuk@suse.de
- Fix build on 8.2 (coreutils) [Bug #24895]
* Fri Jan 31 2003 kukuk@suse.de
- Fix build patch from bk.
* Wed Jan 29 2003 kukuk@suse.de
- Add workaround for duplicate packages for different archs
- Add support for upcoming 8.2
* Fri Oct  4 2002 bk@suse.de
- integrate 8.1 diff into tarball and update README
- build.dif: init_buildsystem: add support for earlyer distributions
* Mon Sep  9 2002 mls@suse.de
- Adjust for SuSE Linux 8.1 again
- Fix parameter parsing
- Changed build to accept .src.rpm sources
* Mon Aug 19 2002 kukuk@suse.de
- Adjust for SuSE Linux 8.1
* Tue Jul 30 2002 kukuk@suse.de
- Fix get_version_number.sh
* Thu Jul 18 2002 kukuk@suse.de
- Don't create /etc/rc.config
* Wed Jul  3 2002 kukuk@suse.de
- Add default package list for new spec files without usedforbuild
- Make it work with gcc 2.95 and gcc 3.1
* Thu Mar  7 2002 kukuk@suse.de
- Fix build/init_buildsystem
* Mon Jan 14 2002 kukuk@suse.de
- Add manual page from Gerd Knorr
* Fri Dec 14 2001 kukuk@suse.de
- Fix file list
- Ignore new RPMs from pre-8.0 on 7.3
* Fri Dec 14 2001 kukuk@suse.de
- More fixes
* Tue Nov 27 2001 kukuk@suse.de
- New build script which uses "usedforbuild"
* Thu Jan 18 2001 kukuk@suse.de
- Update Readme and init_buildsystem for 7.1
* Thu Nov 30 2000 kukuk@suse.de
- Update init_buildsystem, add README
* Wed Nov 15 2000 kukuk@suse.de
- First version
